@@ -1,3 +1,3 @@
-from .base import SelectedBackend, SEOBackendBase
+from .base import SelectedBackend, SelectedBackendMixin, SEOBackendBase
 from .prerender import PrerenderHosted, PrerenderIO
 from .test import TestBackend, TestServiceDownBackend
