@@ -1,10 +1,12 @@
+from __future__ import unicode_literals
+
 from django.test import TestCase
-from django.test.utils import override_settings
 from httmock import all_requests, HTTMock
 
+from django_seo_js.tests.utils import override_settings
 from django_seo_js.backends import PrerenderIO
 
-MOCK_RESPONSE = "<html><body><h1>Hello, World!</h1></body></html>"
+MOCK_RESPONSE = b"<html><body><h1>Hello, World!</h1></body></html>"
 MOCK_RESPONSE_HEADERS = {"foo": "bar"}
 MOCK_RECACHE_RESPONSE = "OK"
 MOCK_RECACHE_HEADERS = {"ibbity": "ack"}
@@ -30,11 +32,11 @@ def mock_prerender_response(url, request):
 
 class PrerenderIOTestToken(TestCase):
 
-    @override_settings(SEO_JS_PRERENDER_TOKEN=None)
+    @override_settings(PRERENDER_TOKEN=None)
     def test_get_token_throws_exception_if_missing(self):
         self.assertRaises(ValueError, PrerenderIO)
 
-    @override_settings(SEO_JS_PRERENDER_TOKEN="123124341adfsaf")
+    @override_settings(PRERENDER_TOKEN="123124341adfsaf")
     def test_get_token(self):
         self.backend = PrerenderIO()
         # Test function
